@@ -20,7 +20,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: scim_uim_imengine.cpp,v 1.12 2005/08/08 03:08:34 suzhe Exp $
+ * $Id: scim_uim_imengine.cpp,v 1.15 2007/04/10 05:43:59 makeinu Exp $
  */
 
 #define Uses_SCIM_UTILITY
@@ -34,6 +34,7 @@
 
 #include <scim.h>
 #include "scim_uim_imengine.h"
+#include <uim/uim-compat-scm.h>
 
 #define scim_module_init uim_LTX_scim_module_init
 #define scim_module_exit uim_LTX_scim_module_exit
@@ -696,20 +697,28 @@ UIMInstance::uim_prop_list_update_cb (void *ptr, const char *str)
         for (size_t i = 0; i < prop_strings.size (); ++ i) {
             if (prop_strings [i].length () < 1) continue;
             scim_split_string_list (prop_values, prop_strings [i], '\t');
-            if (prop_values.size () < 3) continue;
+            if (prop_values.size () < 4) continue;
 
             if (prop_values [0] == "branch") {
                 ++ branch_count;
+
+                // skip im-switch menu
+                if (branch_count == 1 && uim_scm_symbol_value_bool("toolbar-show-action-based-switcher-button?"))
+                    continue;
+
                 snprintf (buf, 256, "/IMEngine/UIM/branch%d", branch_count);
 
-                Property prop (buf, prop_values [1], String (""), prop_values [2]);
+                Property prop (buf, prop_values [2], String (""), prop_values [3]);
                 this_ptr->m_properties.push_back (prop);
 
                 SCIM_DEBUG_IMENGINE(3) << "SCIM Prop = " << buf << "\n";
-            } else if (prop_values [0] == "leaf" && prop_values.size () >= 5) {
-                snprintf (buf, 256, "/IMEngine/UIM/branch%d/%s", branch_count, prop_values [4].c_str ());
+            } else if (prop_values [0] == "leaf" && prop_values.size () >= 6) {
+                if (branch_count == 1 && uim_scm_symbol_value_bool("toolbar-show-action-based-switcher-button?"))
+                    continue;
 
-                Property prop (buf, prop_values [2], String (""), prop_values [3]);
+                snprintf (buf, 256, "/IMEngine/UIM/branch%d/%s", branch_count, prop_values [5].c_str ());
+
+                Property prop (buf, prop_values [3], String (""), prop_values [4]);
                 this_ptr->m_properties.push_back (prop);
 
                 SCIM_DEBUG_IMENGINE(3) << "SCIM Prop = " << buf << "\n";
@@ -822,40 +831,6 @@ UIMInstance::uim_cand_deactive_cb (void *ptr)
         this_ptr->m_show_lookup_table = false;
     }
 }
-
-void
-UIMInstance::uim_surrounding_text_request_cb (void *ptr)
-{
-    UIMInstance *this_ptr = static_cast <UIMInstance *> (ptr);
-    if (this_ptr) {
-
-        SCIM_DEBUG_IMENGINE(2) << "uim_surrounding_text_request_cb.\n";
-
-        WideString wstr;
-        int cursor;
-
-        if (this_ptr->get_surrounding_text (wstr, cursor)) {
-            String str = utf8_wcstombs (wstr);
-            uim_set_surrounding_text (this_ptr->m_uc, str.c_str (), cursor, wstr.length ());
-        }
-    }
-}
-
-int
-UIMInstance::uim_surrounding_text_delete_cb  (void *ptr, int offset, int len)
-{
-    UIMInstance *this_ptr = static_cast <UIMInstance *> (ptr);
-    int ret = -1;
-
-    if (this_ptr) {
-        SCIM_DEBUG_IMENGINE(2) << "uim_surrounding_text_delete_cb.\n";
-        
-        if (this_ptr->delete_surrounding_text (offset, len))
-            ret = 0;
-    }
-
-    return ret;
-}
 /*
 vi:ts=4:nowrap:ai:expandtab
 */
