@@ -20,7 +20,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: scim_uim_imengine.h,v 1.5 2005/08/08 03:08:34 suzhe Exp $
+ * $Id: scim_uim_imengine.h,v 1.7 2007/04/10 04:36:37 makeinu Exp $
  */
 
 #if !defined (__SCIM_UIM_IMENGINE_H)
@@ -104,9 +104,6 @@ private:
     static void uim_cand_select_cb       (void *ptr, int index);
     static void uim_cand_shift_page_cb   (void *ptr, int dir);
     static void uim_cand_deactive_cb     (void *ptr);
-
-    static void uim_surrounding_text_request_cb (void *ptr);
-    static int  uim_surrounding_text_delete_cb  (void *ptr, int offset, int len);
 };
 #endif
 /*
